<?php

namespace QUI\Instagram;

use QUI;
use MetzWeb\Instagram\Instagram;

/**
 * Class Handler
 * @package QUI\Instagram
 */
class Handler
{
    /**
     * Return the database table name from the instagram users
     *
     * @return string
     */
    public static function getUserDatabaseTableName()
    {
        return QUI::getDBTableName('instagram_users');
    }

    /**
     * Return the instagram connection from an user
     *
     * @param string $instagramUsername
     * @return Instagram
     *
     * @throws QUI\Exception
     */
    public static function getConnectionByUser($instagramUsername)
    {
        $result = QUI::getDataBase()->fetch(array(
            'from' => QUI\Instagram\Handler::getUserDatabaseTableName(),
            'where' => array(
                'username' => $instagramUsername
            )
        ));

        if (!isset($result[0])) {
            throw new QUI\Exception(array(
                'quiqqer/instagram',
                'exception.instagramuser.not.found'
            ));
        }

        $data       = $result[0];
        $Connection = self::getClient();

        $Connection->setAccessToken($data['oauth_token']);

        return $Connection;
    }

    /**
     * Return the instagram client
     *
     * @return Instagram
     */
    public static function getClient()
    {
        $Instagram = QUI::getPackage('quiqqer/instagram');

        return new Instagram(array(
            'apiKey' => $Instagram->getConfig()->get('auth', 'INSTAGRAM_CLIENT_ID'),
            'apiSecret' => $Instagram->getConfig()->get('auth', 'INSTAGRAM_CLIENT_SECRET'),
            'apiCallback' => HOST . URL_OPT_DIR . 'quiqqer/instagram/bin/auth/callback.php'
        ));
    }

    /**
     * Return all instagram users in the system
     *
     * @return array
     */
    public static function getInstagramUser()
    {
        $result = QUI::getDataBase()->fetch(array(
            'select' => 'username',
            'from' => QUI\Instagram\Handler::getUserDatabaseTableName()
        ));

        $usernames = array();

        foreach ($result as $entry) {
            $usernames[] = $entry['username'];
        }

        return $usernames;
    }
}
